@@ -15,9 +15,9 @@ CONFUSABLES_CHARS = {
         # WhiteSpaceChars.EM_QUAD_1.value,
         WhiteSpaceChars.EN_SPACE_1_2.value,
         WhiteSpaceChars.EM_SPACE_1.value,
-        # WhiteSpaceChars.THREE_PER_EM_SPACE_1_3.value,
+        WhiteSpaceChars.THREE_PER_EM_SPACE_1_3.value,
         # WhiteSpaceChars.FOUR_PER_EM_SPACE_1_4.value,
-        # WhiteSpaceChars.SIX_PER_EM_SPACE_1_6.value,
+        WhiteSpaceChars.SIX_PER_EM_SPACE_1_6.value,
         # WhiteSpaceChars.FIGURE_SPACE_LIKE_DIGITS.value,
         # WhiteSpaceChars.PUNCTUATION_SPACE_LIKE_DOT.value,
         # WhiteSpaceChars.THIN_SPACE_1_6.value,
